@@ -1,7 +1,8 @@
 from typing import Tuple, Dict, List
 from typing import Tuple, Dict, List
-
+import javalang
 from aibolit.types_decl import LineNumber
+from aibolit.utils.ast import AST
 from aibolit.utils.utils import RemoveComments
 
 
@@ -10,32 +11,11 @@ class StringConcatFinder:
     def __init__(self):
         pass
 
-    """
-        @todo #131:30min NoComments implementation of Ast
-         this __file_to_ast implementation differs from usual ones since it
-         removes the comments from it. Implement a decorator to Ast which does
-         it and replace it here. Don't forget the tests.
-    """
-
-    def __file_to_ast(self, filename: str) -> Tuple[str, Dict[str, int]]:
-        """
-        Takes path to java class file and returns AST Tree
-        :param filename:
-        :return: Tree
-        """
-        with open(filename, encoding='utf-8') as file:
-            text = file.read()
-            lines_map = {line: i for i, line in enumerate(text.splitlines(), start=1)}
-            res = RemoveComments.remove_comments(text)
-
-        return res, lines_map
-
     # flake8: noqa: C901
     def value(self, filename: str) -> List[LineNumber]:
-        import javalang
+
         lines = set()
-        with open(filename, encoding='utf-8') as file:
-            text = javalang.parse.parse(file.read())
+        text = AST(filename).value()
 
         for _, node in text.filter(javalang.tree.BinaryOperation):
             if node.operator == '+':
@@ -48,7 +28,7 @@ class StringConcatFinder:
                 is_l_this = isinstance(node.operandl, javalang.tree.This)
                 is_r_this = isinstance(node.operandr, javalang.tree.This)
                 if is_l_literal and (is_r_member or is_r_meth_inv or is_r_this):
-                    is_string_literal = '"' in node.operandl.value
+                    is_string_literal = '"' in node.operandl.value  # type: ignore
                     if is_string_literal:
                         if node.operandl.position:
                             lines.add(node.operandl.position.line)
@@ -59,7 +39,7 @@ class StringConcatFinder:
                         elif hasattr(node.operandr, '_position'):
                             lines.add(node.operandr._position.line)
                 elif is_r_literal and (is_l_member or is_l_meth_inv or is_l_this):
-                    is_string_literal = '"' in node.operandr.value
+                    is_string_literal = '"' in node.operandr.value  # type: ignore
                     if is_string_literal:
                         if node.operandl.position:
                             lines.add(node.operandl.position.line)
